---
title: "On the Liberty of Thought and Discussion"
author: "John Stuart Mill"
image: /img/jsmill.jpg
era: "Early Modern"
topic: "Free Speech"
draft: false
---

*The following is an excerpt from chapter two of John Stuart Mill’s ‘On Liberty’.*

***On The Liberty of Thought and Discussion\***

THE TIME, IT IS TO BE HOPED, IS GONE BY WHEN ANY DEFENCE WOULD be necessary of the “liberty of the press” as one of the securities against corrupt or tyrannical government. No argument, we may suppose, can now be needed, against permitting a legislature or an executive, not identified in interest with the people, to prescribe opinions to them, and determine what doctrines or what arguments they shall be allowed to hear. This aspect of the question, besides, has been so often and so triumphantly enforced by preceding writers, that it needs not be specially insisted on in this place. Though the law of England, on the subject of the press, is as servile to this day as it was in the time of the Tudors, there is little danger of its being actually put in force against political discussion, except during some temporary panic, when fear of insurrection drives ministers and judges from their propriety; and, speaking generally, it is not, in constitutional countries, to be apprehended that the government, whether completely responsible to the people or not, will often attempt to control the expression of opinion, except when in doing so it makes itself the organ of the general intolerance of the public. Let us suppose, therefore, that the government is entirely at one with the people, and never thinks of exerting any power of coercion unless in agreement with what it conceives to be their voice. But I deny the right of the people to exercise such coercion, either by themselves or by their government. The power itself is illegitimate. The best government has no more title to it than the worst. It is as noxious, or more noxious, when exerted in accordance with public opinion, than when in opposition to it. If all mankind minus one, were of one opinion, and only one person were of the contrary opinion, mankind would be no more justified in silencing that one person, than he, if he had the power, would be justified in silencing mankind. Were an opinion a personal possession of no value except to the owner; if to be obstructed in the enjoyment of it were simply a private injury, it would make some difference whether the injury was inflicted only on a few persons or on many. But the peculiar evil of silencing the expression of an opinion is, that it is robbing the human race; posterity as well as the existing generation; those who dissent from the opinion, still more than those who hold it. If the opinion is right, they are deprived of the opportunity of exchanging error for truth: if wrong, they lose, what is almost as great a benefit, the clearer perception and livelier impression of truth, produced by its collision with error.

It is necessary to consider separately these two hypotheses, each of which has a distinct branch of the argument corresponding to it. We can never be sure that the opinion we are endeavoring to stifle is a false opinion; and if we were sure, stifling it would be an evil still.

First: the opinion which it is attempted to suppress by authority may possibly be true. Those who desire to suppress it, of course deny its truth; but they are not infallible. They have no authority to decide the question for all mankind, and exclude every other person from the means of judging. To refuse a hearing to an opinion, because they are sure that it is false, is to assume that their certainty is the same thing as absolute certainty. All silencing of discussion is an assumption of infallibility. Its condemnation may be allowed to rest on this common argument, not the worse for being common.

Unfortunately for the good sense of mankind, the fact of their fallibility is far from carrying the weight in their practical judgment, which is always allowed to it in theory; for while every one well knows himself to be fallible, few think it necessary to take any precautions against their own fallibility, or admit the supposition that any opinion of which they feel very certain, may be one of the examples of the error to which they acknowledge themselves to be liable. Absolute princes, or others who are accustomed to unlimited deference, usually feel this complete confidence in their own opinions on nearly all subjects. People more happily situated, who sometimes hear their opinions disputed, and are not wholly unused to be set right when they are wrong, place the same unbounded reliance only on such of their opinions as are shared by all who surround them, or to whom they habitually defer: for in proportion to a man’s want of confidence in his own solitary judgment, does he usually repose, with implicit trust, on the infallibility of “the world” in general. And the world, to each individual, means the part of it with which he comes in contact; his party, his sect, his church, his class of society: the man may be called, by comparison, almost liberal and large-minded to whom it means anything so comprehensive as his own country or his own age. Nor is his faith in this collective authority at all shaken by his being aware that other ages, countries, sects, churches, classes, and parties have thought, and even now think, the exact reverse. He devolves upon his own world the responsibility of being in the right against the dissentient worlds of other people; and it never troubles him that mere accident has decided which of these numerous worlds is the object of his reliance, and that the same causes which make him a Churchman in London, would have made him a Buddhist or a Confucian in Pekin. Yet it is as evident in itself as any amount of argument can make it, that ages are no more infallible than individuals; every age having held many opinions which subsequent ages have deemed not only false but absurd; and it is as certain that many opinions, now general, will be rejected by future ages, as it is that many, once general, are rejected by the present.

The objection likely to be made to this argument, would probably take some such form as the following. There is no greater assumption of infallibility in forbidding the propagation of error, than in any other thing which is done by public authority on its own judgment and responsibility. Judgment is given to men that they may use it. Because it may be used erroneously, are men to be told that they ought not to use it at all? To prohibit what they think pernicious, is not claiming exemption from error, but fulfilling the duty incumbent on them, although fallible, of acting on their conscientious conviction. If we were never to act on our opinions, because those opinions may be wrong, we should leave all our interests uncared for, and all our duties unperformed. An objection which applies to all conduct can be no valid objection to any conduct in particular.

It is the duty of governments, and of individuals, to form the truest opinions they can; to form them carefully, and never impose them upon others unless they are quite sure of being right. But when they are sure (such reasoners may say), it is not conscientiousness but cowardice to shrink from acting on their opinions, and allow doctrines which they honestly think dangerous to the welfare of mankind, either in this life or in another, to be scattered abroad without restraint, because other people, in less enlightened times, have persecuted opinions now believed to be true. Let us take care, it may be said, not to make the same mistake: but governments and nations have made mistakes in other things, which are not denied to be fit subjects for the exercise of authority: they have laid on bad taxes, made unjust wars. Ought we therefore to lay on no taxes, and, under whatever provocation, make no wars? Men, and governments, must act to the best of their ability. There is no such thing as absolute certainty, but there is assurance sufficient for the purposes of human life. We may, and must, assume our opinion to be true for the guidance of our own conduct: and it is assuming no more when we forbid bad men to pervert society by the propagation of opinions which we regard as false and pernicious.

I answer, that it is assuming very much more. There is the greatest difference between presuming an opinion to be true, because, with every opportunity for contesting it, it has not been refuted, and assuming its truth for the purpose of not permitting its refutation. Complete liberty of contradicting and disproving our opinion, is the very condition which justifies us in assuming its truth for purposes of action; and on no other terms can a being with human faculties have any rational assurance of being right.

When we consider either the history of opinion, or the ordinary conduct of human life, to what is it to be ascribed that the one and the other are no worse than they are? Not certainly to the inherent force of the human understanding; for, on any matter not self-evident, there are ninety-nine persons totally incapable of judging of it, for one who is capable; and the capacity of the hundredth person is only comparative; for the majority of the eminent men of every past generation held many opinions now known to be erroneous, and did or approved numerous things which no one will now justify. Why is it, then, that there is on the whole a preponderance among mankind of rational opinions and rational conduct? If there really is this preponderance—which there must be, unless human affairs are, and have always been, in an almost desperate state— it is owing to a quality of the human mind, the source of everything respectable in man, either as an intellectual or as a moral being, namely, that his errors are corrigible. He is capable of rectifying his mistakes by discussion and experience. Not by experience alone. There must be discussion, to show how experience is to be interpreted. Wrong opinions and practices gradually yield to fact and argument: but facts and arguments, to produce any effect on the mind, must be brought before it. Very few facts are able to tell their own story, without comments to bring out their meaning. The whole strength and value, then, of human judgment, depending on the one property, that it can be set right when it is wrong, reliance can be placed on it only when the means of setting it right are kept constantly at hand. In the case of any person whose judgment is really deserving of confidence, how has it become so? Because he has kept his mind open to criticism of his opinions and conduct. Because it has been his practice to listen to all that could be said against him; to profit by as much of it as was just, and expound to himself, and upon occasion to others, the fallacy of what was fallacious. Because he has felt, that the only way in which a human being can make some approach to knowing the whole of a subject, is by hearing what can be said about it by persons of every variety of opinion, and studying all modes in which it can be looked at by every character of mind. No wise man ever acquired his wisdom in any mode but this; nor is it in the nature of human intellect to become wise in any other manner. The steady habit of correcting and completing his own opinion by collating it with those of others, so far from causing doubt and hesitation in carrying it into practice, is the only stable foundation for a just reliance on it: for, being cognizant of all that can, at least obviously, be said against him, and having taken up his position against all gainsayers knowing that he has sought for objections and difficulties, instead of avoiding them, and has shut out no light which can be thrown upon the subject from any quarter—he has a right to think his judgment better than that of any person, or any multitude, who have not gone through a similar process.

It is not too much to require that what the wisest of mankind, those who are best entitled to trust their own judgment, find necessary to warrant their relying on it, should be submitted to by that miscellaneous collection of a few wise and many foolish individuals, called the public. The most intolerant of churches, the Roman Catholic Church, even at the canonization of a saint, admits, and listens patiently to, a “devil’s advocate.” The holiest of men, it appears, cannot be admitted to posthumous honors, until all that the devil could say against him is known and weighed. If even the Newtonian philosophy were not permitted to be questioned, mankind could not feel as complete assurance of its truth as they now do. The beliefs which we have most warrant for, have no safeguard to rest on, but a standing invitation to the whole world to prove them unfounded. If the challenge is not accepted, or is accepted and the attempt fails, we are far enough from certainty still; but we have done the best that the existing state of human reason admits of; we have neglected nothing that could give the truth a chance of reaching us: if the lists are kept open, we may hope that if there be a better truth, it will be found when the human mind is capable of receiving it; and in the meantime we may rely on having attained such approach to truth, as is possible in our own day. This is the amount of certainty attainable by a fallible being, and this the sole way of attaining it.

Strange it is, that men should admit the validity of the arguments for free discussion, but object to their being “pushed to an extreme;” not seeing that unless the reasons are good for an extreme case, they are not good for any case. Strange that they should imagine that they are not assuming infallibility when they acknowledge that there should be free discussion on all subjects which can possibly be doubtful, but think that some particular principle or doctrine should be forbidden to be questioned because it is so certain, that is, because they are certain that it is certain. To call any proposition certain, while there is any one who would deny its certainty if permitted, but who is not permitted, is to assume that we ourselves, and those who agree with us, are the judges of certainty, and judges without hearing the other side.

In the present age—which has been described as “destitute of faith, but terrified at scepticism,”—in which people feel sure, not so much that their opinions are true, as that they should not know what to do without them—the claims of an opinion to be protected from public attack are rested not so much on its truth, as on its importance to society. There are, it is alleged, certain beliefs, so useful, not to say indispensable to well-being, that it is as much the duty of governments to uphold those beliefs, as to protect any other of the interests of society. In a case of such necessity, and so directly in the line of their duty, something less than infallibility may, it is maintained, warrant, and even bind, governments, to act on their own opinion, confirmed by the general opinion of mankind. It is also often argued, and still oftener thought, that none but bad men would desire to weaken these salutary beliefs; and there can be nothing wrong, it is thought, in restraining bad men, and prohibiting what only such men would wish to practise. This mode of thinking makes the justification of restraints on discussion not a question of the truth of doctrines, but of their usefulness; and flatters itself by that means to escape the responsibility of claiming to be an infallible judge of opinions. But those who thus satisfy themselves, do not perceive that the assumption of infallibility is merely shifted from one point to another. The usefulness of an opinion is itself matter of opinion: as disputable, as open to discussion and requiring discussion as much, as the opinion itself. There is the same need of an infallible judge of opinions to decide an opinion to be noxious, as to decide it to be false, unless the opinion condemned has full opportunity of defending itself. And it will not do to say that the heretic may be allowed to maintain the utility or harmlessness of his opinion, though forbidden to maintain its truth. The truth of an opinion is part of its utility. If we would know whether or not it is desirable that a proposition should be believed, is it possible to exclude the consideration of whether or not it is true? In the opinion, not of bad men, but of the best men, no belief which is contrary to truth can be really useful: and can you prevent such men from urging that plea, when they are charged with culpability for denying some doctrine which they are told is useful, but which they believe to be false? Those who are on the side of received opinions, never fail to take all possible advantage of this plea; you do not find them handling the question of utility as if it could be completely abstracted from that of truth: on the contrary, it is, above all, because their doctrine is “the truth,” that the knowledge or the belief of it is held to be so indispensable. There can be no fair discussion of the question of usefulness, when an argument so vital may be employed on one side, but not on the other. And in point of fact, when law or public feeling do not permit the truth of an opinion to be disputed, they are just as little tolerant of a denial of its usefulness. The utmost they allow is an extenuation of its absolute necessity or of the positive guilt of rejecting it.

In order more fully to illustrate the mischief of denying a hearing to opinions because we, in our own judgment, have condemned them, it will be desirable to fix down the discussion to a concrete case; and I choose, by preference, the cases which are least favourable to me—in which the argument against freedom of opinion, both on the score of truth and on that of utility, is considered the strongest. Let the opinions impugned be the belief in a God and in a future state, or any of the commonly received doctrines of morality. To fight the battle on such ground, gives a great advantage to an unfair antagonist; since he will be sure to say (and many who have no desire to be unfair will say it internally), Are these the doctrines which you do not deem sufficiently certain to be taken under the protection of law? Is the belief in a God one of the opinions, to feel sure of which, you hold to be assuming infallibility? But I must be permitted to observe, that it is not the feeling sure of a doctrine (be it what it may) which I call an assumption of infallibility. It is the undertaking to decide that question for others, without allowing them to hear what can be said on the contrary side. And I denounce and reprobate this pretension not the less, if put forth on the side of my most solemn convictions. However positive any one’s persuasion may be, not only of the falsity, but of the pernicious consequences—not only of the pernicious consequences, but (to adopt expressions which I altogether condemn) the immorality and impiety of an opinion; yet if, in pursuance of that private judgment, though backed by the public judgment of his country or his contemporaries, he prevents the opinion from being heard in its defence, he assumes infallibility. And so far from the assumption being less objectionable or less dangerous because the opinion is called immoral or impious, this is the case of all others in which it is most fatal. These are exactly the occasions on which the men of one generation commit those dreadful mistakes which excite the astonishment and horror of posterity. It is among such that we find the instances memorable in history, when the arm of the law has been employed to root out the best men and the noblest doctrines; with deplorable success as to the men, though some of the doctrines have survived to be (as if in mockery) invoked, in defence of similar conduct towards those who dissent from them, or from their received interpretation.

Mankind can hardly be too often reminded, that there was once a man named Socrates, between whom and the legal authorities and public opinion of his time, there took place a memorable collision. Born in an age and country abounding in individual greatness, this man has been handed down to us by those who best knew both him and the age, as the most virtuous man in it; while we know him as the head and prototype of all subsequent teachers of virtue, the source equally of the lofty inspiration of Plato and the judicious utilitarianism of Aristotle, “i maestri di color che sanno,” the two headsprings of ethical as of all other philosophy. This acknowledged master of all the eminent thinkers who have since lived—whose fame, still growing after more than two thousand years, all but outweighs the whole remainder of the names which make his native city illustrious—was put to death by his countrymen, after a judicial conviction, for impiety and immorality. Impiety, in denying the gods recognized by the State; indeed, his accuser asserted (see the “Apologia”) that he believed in no gods at all. Immorality, in being, by his doctrines and instructions, a “corrupter of youth.” Of these charges the tribunal, there is every ground for believing, honestly found him guilty, and condemned the man who probably of all then born had deserved best of mankind, to be put to death as a criminal.

To pass from this to the only other instance of judicial iniquity, the mention of which, after the condemnation of Socrates, would not be an anti-climax: the event which took place on Calvary rather more than eighteen hundred years ago. The man who left on the memory of those who witnessed his life and conversation, such an impression of his moral grandeur, that eighteen subsequent centuries have done homage to him as the Almighty in person, was ignominiously put to death, as what? As a blasphemer. Men did not merely mistake their benefactor; they mistook him for the exact contrary of what he was, and treated him as that prodigy of impiety, which they themselves are now held to be, for their treatment of him. The feelings with which mankind now regard these lamentable transactions, especially the latter of the two, render them extremely unjust in their judgment of the unhappy actors. These were, to all appearance, not bad men—not worse than men most commonly are, but rather the contrary; men who possessed in a full, or somewhat more than a full measure, the religious, moral, and patriotic feelings of their time and people: the very kind of men who, in all times, our own included, have every chance of passing through life blameless and respected. The high-priest who rent his garments when the words were pronounced, which, according to all the ideas of his country, constituted the blackest guilt, was in all probability quite as sincere in his horror and indignation, as the generality of respectable and pious men now are in the religious and moral sentiments they profess; and most of those who now shudder at his conduct, if they had lived in his time and been born Jews, would have acted precisely as he did. Orthodox Christians who are tempted to think that those who stoned to death the first martyrs must have been worse men than they themselves are, ought to remember that one of those persecutors was Saint Paul.